@@ -2,10 +2,10 @@ from __future__ import annotations
 
 
 def function_with_py310_annotations(
-    self,  # noqa: ANN001, ARG001
-    x: bool | None,  # noqa: ARG001
-    y: int | str | float,  # noqa: ARG001
-    z: str | None = None,  # noqa: ARG001
+    self,  # noqa: ANN001
+    x: bool | None,
+    y: int | str | float,  # noqa: PYI041
+    z: str | None = None,
 ) -> str:
     """
     Method docstring.
