@@ -1,13 +1,11 @@
 """Module demonstrating imports that are type guarded"""
+
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+import datetime
 
 from attrs import define
 
-if TYPE_CHECKING:
-    import datetime
-
 
 @define()
 class SomeClass:
@@ -19,7 +17,7 @@ class SomeClass:
     @classmethod
     def from_str(cls, input_value: str) -> SomeClass:
         """
-        Initialise from string
+        Initialize from string
 
         :param input_value: Input
         :return: result
@@ -29,7 +27,7 @@ class SomeClass:
     @classmethod
     def from_date(cls, input_value: datetime.date) -> SomeClass:
         """
-        Initialise from date
+        Initialize from date
 
         :param input_value: Input
         :return: result
@@ -39,14 +37,14 @@ class SomeClass:
     @classmethod
     def from_time(cls, input_value: datetime.time) -> SomeClass:
         """
-        Initialise from time
+        Initialize from time
 
         :param input_value: Input
         :return: result
         """
         return cls(input_value)
 
-    def calculate_thing(self, number: float) -> datetime.timedelta:
+    def calculate_thing(self, number: float) -> datetime.timedelta:  # noqa: PLR6301
         """
         Calculate a thing
 
